==> hermes-5.3.0.18.tar.gz: hermes-5.3.0.18/app/lib/notifications_center/user.rb <==
module NotificationsCenter
  class User < Base
    KEYS = NOTIFICATION_KEYS[:user]

    def initialize(*arg)
      super
      @user = @instance.notifiable
      @request = @user.main_applicant&.first_active_request
    end
    
    def full_name
      @request.requester_firstname.capitalize
    end 

    def title
      case @key        
      when KEYS[:create]
        "#{NAME} - Création de votre compte"
      when KEYS[:new_reserved_offer]
        "Action Logement Services AL'In Logement exclusif #{@request.entity&.title}"
      else
        ''
      end
    end

    def body
      case @key        
      when KEYS[:create]
        username = @instance.datas[:username]
        "
          Nous vous confirmons votre inscription sur votre plateforme de demande de logement.\n
          Votre identifiant  : #{username}
        "
      when KEYS[:new_reserved_offer]
        str = "
        <table>
          <tbody>
            <tr>
              <td style='padding: 8px 0;'>De nouvelles offres de logement sont disponibles sur votre plateforme AL’In : ces logements sont exclusivement proposés aux salariés de votre entreprise.</td>
            </tr>
            <tr>
              <td style='padding: 8px 0;'>Consultez les offres susceptibles de vous intéresser et candidatez.</td>
            </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        @instance.datas[:offer_ids].each do |offer_id|
          offer = Hermes::HousingOffer.find(offer_id)
          url = "#{HERMES_CONFIG["frontend_url"]}/#/fiche-logement/#{offer.id}?mail=true"
          str += "
          <tr style='vertical-align: top;'>
            <td style='padding: 8px 32px 8px 0;'>
              <a href='#{url}' target='_blank' style='display: block; min-height: 100px; max-height: 100px; background-image: url(#{HERMES_CONFIG["new_reserved_offer_alt_img_url"]}); background-size: 100% 100%;'>
                <img src='#{offer.picture_for_email}' alt=' ' height='100px' width='160px' style='object-fit: cover;'/>
              </a>
            </td>
            <td style='padding: 8px;'>
              <div style='height: 84px;'>
                <b>#{offer.district} (#{offer.department}) - #{offer.surface}m² - #{offer.typology}</b> <br/>
                #{offer.rent_with_charges} € 
              </div>
              <a href='#{url}' target='_blank' style='color:rgb(0, 0, 238); text-decoration: underline; bottom: 0; left: 0;'>En savoir plus</a>
            </td>
          </tr>
          "
        end
        str += "</table></tbody>"
      else
        ''
      end
    end

    def actions
      case @key          
        when KEYS[:create]
          {
            title: 'Me connecter',
            link: '#connexion-demandeur'
          }
        when KEYS[:new_reserved_offer]
          {
            title: 'Voir les offres',
            link: '#/HomeSalarie?mail=true'
          }
        else
          ''
      end
    end

    def header_text
      case @key
      when KEYS[:new_reserved_offer]
        "
          Des nouvelles offres sont disponibles <br/>
        "
      else
        ""
      end 
    end 
  end
end

==> hermes-5.3.0.28.tar.gz: hermes-5.3.0.28/app/lib/notifications_center/user.rb <==
module NotificationsCenter
  class User < Base
    KEYS = NOTIFICATION_KEYS[:user]

    def initialize(*arg)
      super
      @user = @instance.notifiable
      @request = @user.main_applicant&.first_active_request
    end
    
    def full_name
      @request.requester_firstname.capitalize
    end 

    def title
      case @key        
      when KEYS[:create]
        "#{NAME} - Création de votre compte"
      when KEYS[:new_reserved_offer]
        "Action Logement Services AL'In Logement exclusif #{@request.entity&.title}"
      when KEYS[:new_published_offer]
        "Action Logement Services _AL'In_ De nouvelles offres sont disponibles"
      else
        ''
      end
    end

    def body
      case @key        
      when KEYS[:create]
        username = @instance.datas[:username]
        "
          Nous vous confirmons votre inscription sur votre plateforme de demande de logement.\n
          Votre identifiant  : #{username}
        "
      when KEYS[:new_published_offer]
        str = "
        <table>
          <tbody>
            <tr>
              <td style='padding: 8px 0;'>De nouvelles offres de logements sont disponibles sur votre plateforme AL’in. Consultez les offres susceptibles de vous intéresser et candidatez.</td>
            </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
        print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
        str += "
        Nous vous invitons à consulter toutes les offres disponibles en ligne. 
"
      when KEYS[:new_reserved_offer]
        str = "
        <table>
          <tbody>
            <tr>
              <td style='padding: 8px 0;'>De nouvelles offres de logement sont disponibles sur votre plateforme AL’In : ces logements sont exclusivement proposés aux salariés de votre entreprise.</td>
            </tr>
            <tr>
              <td style='padding: 8px 0;'>Consultez les offres susceptibles de vous intéresser et candidatez.</td>
            </tr>
          </tbody>
        </table>
        "
        str += "<table><tbody>"
       print_offer_list( @instance.datas[:offer_ids])
        str += "</table></tbody>"
        str += "
        Nous vous invitons à consulter toutes les offres disponibles en ligne. 
"
      else
        ''
      end
    end

    def print_offer_list(offers_ids)
      offers_ids.each do |offer_id|
        offer = Hermes::HousingOffer.find(offer_id)
        url = "#{HERMES_CONFIG["frontend_url"]}/#/fiche-logement/#{offer.id}?mail=true"
        str += "
          <tr style='vertical-align: top;'>
            <td style='padding: 8px 32px 8px 0;'>
              <a href='#{url}' target='_blank' style='display: block; min-height: 100px; max-height: 100px; background-image: url(#{HERMES_CONFIG["new_reserved_offer_alt_img_url"]}); background-size: 100% 100%;'>
                <img src='#{offer.picture_for_email}' alt=' ' height='100px' width='160px' style='object-fit: cover;'/>
              </a>
            </td>
            <td style='padding: 8px;'>
              <div style='height: 84px;'>
                <b>#{offer.district} (#{offer.department}) - #{offer.surface}m² - #{offer.typology}</b> <br/>
                #{offer.rent_with_charges} € 
              </div>
              <a href='#{url}' target='_blank' style='color:rgb(0, 0, 238); text-decoration: underline; bottom: 0; left: 0;'>En savoir plus</a>
            </td>
          </tr>
          "
      end
    end

    def actions
      case @key          
        when KEYS[:create]
          {
            title: 'Me connecter',
            link: '#connexion-demandeur'
          }
        when KEYS[:new_reserved_offer],KEYS[:new_published_offer] 
          {
            title: 'Voir les offres',
            link: '#/HomeSalarie?mail=true'
          }
        else
          ''
      end
    end

    def header_text
      case @key
      when KEYS[:new_reserved_offer], KEYS[:new_published_offer] 
        "
          Des nouvelles offres sont disponibles <br/>
        "
      else
        ""
      end 
    end 
  end
end
